###### DPM code #######

DPM <- function(Beta.obs, Delta, C.init, pi.alpha, iteration, thin, seed=12345) {

library(mvtnorm)
  
  K <- ncol(Beta.obs)
  G <- nrow(Delta)/ K
  
  update.c <- function(z.mat,c.assign,i) {
    
    cluster.pool<-c(unique(c.assign),max(unique(c.assign))+1)
    z.i <- z.mat[i,]
    
    prob.c <- sapply(unique(c.assign), FUN=function(x) {
      cluster.size <- length(which(c.assign==x))
      cluster.ind <- which(c.assign==x)
      if(cluster.size>1) {z.ave.cluster <- apply(z.mat[cluster.ind,],2,mean)} else{
        z.ave.cluster <- z.mat[cluster.ind,]}
      
      ifelse(cluster.size!=0, 
             ( (cluster.size-1) /(G-1+pi.alpha) ) * 
               dmvnorm(x=z.i,mean=(cluster.size/(cluster.size+1))*z.ave.cluster,sigma=diag((cluster.size+2)/(cluster.size+1),K),log=F) , 
             0)},simplify=T )
    
    prob.jump <- ( pi.alpha/(G-1+pi.alpha) ) *
      dmvnorm(x=z.i,mean=rep(0,K),sigma=diag(2,K),log=F)
    
    # prob.c is a vector of length = length(unique(c)) 
    std.prob <- c(prob.c,prob.jump)/(sum(prob.c)+prob.jump) 
    sample(cluster.pool,size=1,prob=std.prob)
  }
  
  rnd = iteration/thin
  ClusterOut <- matrix(0,nrow=G,ncol=rnd+1)
  set.seed(seed)
  ClusterOut[,1] <- sample(1:C.init,size=G,replace=T)  
  sign.vector<-c(apply(Beta.obs,1,sign))   
  
  for (i in 1:rnd ) {    
    start <- proc.time()
    c.assign.old <- ClusterOut[,i]
    prob.vector <- apply(Delta[,(1+thin*(i-1)):(thin*i)],1,mean)
    scale.prob.vector <-  (prob.vector*sign.vector+1)/2  
    z.vec <- qnorm(scale.prob.vector) 
    z.vec[which(z.vec> 3)] <- 4
    z.vec[which(z.vec< -3)] <- -4
    z.mat <- matrix(z.vec,byrow=T,nrow=G,ncol=K)  ## observed data for clustering
    c.assign.cur<-rep(0,G)
    for (g in 1:G) {
      c.assign.cur[g]<-update.c(z.mat=z.mat,c.assign=c.assign.old, i=g)
    }      
    
    end <- proc.time()
    print(end-start)
    print(i)
    print(table(c.assign.cur))
    
    ClusterOut[,i+1] <- c.assign.cur      
    
  }
  
  return(ClusterOut)
  
}
