###################################################
## Reproduce real part ############################
### 16/10/02 ######################################

library("gplots")
library("WGCNA")
library(edgeR)
library(DESeq)
library(MASS)
library(mvtnorm)
library("biomaRt")
library(ConsensusClusterPlus)

source("src/MCMC161002.R")
source("src/DPM161002.R")

### read the data ##

load('dat/micedataG10280.rda')
G <- nrow(Data.list[[1]])
K <- length(Data.list)

### Run the MCMC (single node) ###

lambda.mean<-0
lambda.var<-10
eta.mean <- -7
eta.var<- 10
m.mean <- -2
m.var <- 10

init <- Initialize(Data.list=Data.list,X.list=X.list,
                   lambda.mean=lambda.mean,lambda.var=lambda.var,
                   eta.mean=eta.mean,eta.var=eta.var,
                   m.mean=m.mean,m.var=m.var,seed=12345)

iteration<- 10000
store <- Store(Data.list=Data.list,X.list=X.list,iteration=iteration)                        

MCMC.out <- MCMCRun(Data.list=Data.list,X.list=X.list,Init.value=init,
                    Store.value = store,iteration=iteration,
                    lambda.mean=lambda.mean, lambda.var=lambda.var, 
                    eta.mean=eta.mean, eta.var=eta.var, 
                    m.mean=m.mean, m.var=m.var, seed=12345) 

## the results in the manuscript is based on parallel computing

### Table 1. Number of DEs ###

##Bayes
Full_Delta <- MCMC.out[["Delta"]]
Delta.mean <- apply(Full_Delta[,-c(1:burnin)],1,mean)
delta.combine <- matrix(Delta.mean,byrow=T,nrow=G,ncol=K)

libsize <- lapply(Data.list,colSums)
es_seq =function (y,X,lib) {
       y=array(y)
       v1=log((y[which(X==1)]+1)/(lib[which(X==1)]))
       v2=log((y[which(X==0)]+1)/(lib[which(X==0)]))
       u=mean(v1) - mean(v2)
       return(u)
  }

beta.obs.combine<-matrix(rep(0,G*K),nrow=G,ncol=K) 
for (g in 1:G){
     for (k in 1:K){
         lib<-libsize[[k]]
         beta.obs.combine[g,k]<-es_seq(y=Data.list[[k]][g,],X=X.list[[k]],lib=lib)
    }
}
rownames(delta.combine) <-rownames(beta.obs.combine) <- rownames(Data.list[[1]])
burnin<-3000
source("src/GetBayesianQ161002.R")
q_bayesian <- GetBayesianQ(Delta=Full_Delta,G=G,K=K,burnin=burnin)
genes <- rownames(Data.list[[1]])
names(q_bayesian) <- genes
delta.max <-sapply(1:nrow(delta.combine),FUN=function(x)  {
  max(delta.combine[x,1],delta.combine[x,2],delta.combine[x,3])}  )

de.index <- which(q_bayesian<0.1 & delta.max>0.9)
length(de.index)
de.index <- which(q_bayesian<0.05 & delta.max>0.95)
length(de.index)

##edgeR

data1<-Data.list[[1]]
data2<-Data.list[[2]]
data3<-Data.list[[3]]
colnames(data1)<-NULL
colnames(data2)<-NULL
colnames(data3)<-NULL
data<-list(data1,data2,data3)
group<-factor(X.list[[1]])

y <- DGEList(counts=data[[1]],group=group)
y <- calcNormFactors(y)
y <- estimateCommonDisp(y)
y <- estimateTagwiseDisp(y)
pseudo.dat1 <- y$pseudo.counts
d=DGEList(counts=data[[1]],group=group)
d <- calcNormFactors(d)
design=model.matrix(~group)
d=estimateGLMCommonDisp(d)
d=estimateGLMTrendedDisp(d)
d=estimateGLMTagwiseDisp(d)
fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef=2)
p_value1=lrt$table[,4]

y <- DGEList(counts=data[[2]],group=group)
y <- calcNormFactors(y)
y <- estimateCommonDisp(y)
y <- estimateTagwiseDisp(y)
pseudo.dat2 <- y$pseudo.counts
d=DGEList(counts=data[[2]],group=group)
d <- calcNormFactors(d)
design=model.matrix(~group)
d=estimateGLMCommonDisp(d)
d=estimateGLMTrendedDisp(d)
d=estimateGLMTagwiseDisp(d)
fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef=2)
p_value2=lrt$table[,4]

y <- DGEList(counts=data[[3]],group=group)
y <- calcNormFactors(y)
y <- estimateCommonDisp(y)
y <- estimateTagwiseDisp(y)
pseudo.dat3 <- y$pseudo.counts
d=DGEList(counts=data[[3]],group=group)
d <- calcNormFactors(d)
design=model.matrix(~group)
d=estimateGLMCommonDisp(d)
d=estimateGLMTrendedDisp(d)
d=estimateGLMTagwiseDisp(d)
fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef=2)
p_value3=lrt$table[,4]

qvalue1<-p.adjust(p_value1,method='BH')
qvalue2<-p.adjust(p_value2,method='BH')
qvalue3<-p.adjust(p_value3,method='BH')

edge.p<-cbind(p_value1,p_value2,p_value3)
rownames(edge.p)<-rownames(data[[1]])

fisher<-function(x) {
  f<-sum(-2*log(x))
  1-pchisq(f,df=2*length(x))
}

q_fisher_edgeR<-p.adjust(apply(edge.p,1,fisher),method='BH')
edgeR_de_index<- which(q_fisher_edgeR<0.1)
length(edgeR_de_index)
edgeR_de_index<- which(q_fisher_edgeR<0.05)
length(edgeR_de_index)

## DESeq

n <- 12
condition=factor(c(rep('A',n),rep('B',n)))
cds1 = newCountDataSet( data[[1]], condition )
cds1 = estimateSizeFactors( cds1 )
cds1 = estimateDispersions( cds1, fitType = c("local") )
res1 = nbinomTest( cds1, "A", "B" )
p1 = res1$pval
q1=res1$padj
cds2 = newCountDataSet( data[[2]], condition )
cds2 = estimateSizeFactors( cds2 )
cds2 = estimateDispersions( cds2, fitType = c("local") )
res2 = nbinomTest( cds2, "A", "B" )
p2 = res2$pval
q2=res2$padj
cds3 = newCountDataSet( data[[3]], condition )
cds3 = estimateSizeFactors( cds3 )
cds3 = estimateDispersions( cds3, fitType = c("local") )
res3 = nbinomTest( cds3, "A", "B" )
p3 = res3$pval
q3=res3$padj

DESeq.p<-cbind(p1,p2,p3)
rownames(DESeq.p)<-rownames(data[[1]])
q_fisher_DESeq<-p.adjust(apply(DESeq.p,1,fisher),method='BH')

DESeq_de_index<- which(q_fisher_DESeq<0.1)
length(DESeq_de_index)
DESeq_de_index<- which(q_fisher_DESeq<0.05)
length(DESeq_de_index)

### Table 2. Three selected genes ###

select.genes <- c('Mir212','Mir384','Alb')
edge.p[select.genes,]
q_fisher_edgeR[select.genes]
DESeq.p[select.genes,]
q_fisher_DESeq[select.genes]
delta.combine[select.genes,]
q_bayesian[select.genes]

apply(pseudo.dat1[select.genes,1:12],1,mean)
apply(pseudo.dat1[select.genes,13:24],1,mean)
apply(pseudo.dat2[select.genes,1:12],1,mean)
apply(pseudo.dat2[select.genes,13:24],1,mean)
apply(pseudo.dat3[select.genes,1:12],1,mean)
apply(pseudo.dat3[select.genes,13:24],1,mean)

pseudo.dat<- list(pseudo.dat1[select.genes,],pseudo.dat2[select.genes,],pseudo.dat3[select.genes,])
#pseudo.dat<- list(Data.list[[1]][select.genes,],Data.list[[2]][select.genes,],Data.list[[3]][select.genes,])
study <- c('HIP','STR','PFC')

#### boxplot, jitter plot
old.par <- par()
pdf('out/Normalized_counts_boxplot.pdf')
par(mfrow=c(3,3))
par(mar=c(2,2,2,1.5))
par(font.lab=2)
par(font.axis=2)
for (i in 1:length(select.genes)) {
  for (k in 1:K) {
    group.f <- as.factor(c(rep('HIV',12),rep('Normal',12)))
    dat <- data.frame(count=pseudo.dat[[k]][i,],group=group.f )
    if(i==3 & k==3) {ylim <- c(0,25)} else if (i==3 & k==1) {
      ylim <- c(0,15) } else {
        ylim <- c(0,max(pseudo.dat[[k]][i,])+1)}  
    boxplot(count~group,data=dat,main=NULL,
            horizontal=F,ylim=ylim,pch=16,xaxt='n',ylab=NULL)
    stripchart(count~group, vertical = TRUE, data = dat,
               method = "jitter", add = TRUE, pch = 16,cex=1.2)
    box(which = "plot", lty = "solid")
  }
}
dev.off()
par(old.par)

### Fig 5. DPM clustering ###

bayes245 <- read.csv('dat/BayesMetaSeq245genes.csv',
                     header=T, stringsAsFactors = F)[,1]
load('dat/DeltaBetaOut245.RData')
rownames(beta245) <- bayes245
index <- sapply(bayes245,function(x) which(genes==x) )
delta245 <- matrix(,nrow=length(index)*K,ncol=iteration)
for (g in 1:length(index)) {
 delta245[((g-1)*K+1):(g*K),] <- Full_Delta[((index[g]-1)*K+1):(index[g]*K),]
}

set.seed(12345)
C.init <- 10 
pi.alpha<- 2   
iteration <- 10000
thin <- 20 
cluster.out <- DPM(Beta.obs = beta245, Delta = delta245,C.init = C.init, pi.alpha = pi.alpha, iteration = iteration, thin = thin) 

copy.upper.lower <- function(m) 
{
  m[lower.tri(m)] <- t(m)[lower.tri(m)]
  m
}

mydist <- function(y) {
  diss.mat <- matrix(,nrow=nrow(y),ncol=nrow(y))
  rownames(diss.mat) <- colnames(diss.mat) <- rownames(y)
  diag(diss.mat) <- 1
  for (i in 1:nrow(diss.mat)) {
    for (j in i:ncol(diss.mat)){
      diss.mat[i,j] <- sum(y[i,]==y[j,])/ncol(y)    
    }
  }
  diss.mat <- copy.upper.lower(diss.mat)
  return(1-diss.mat)
}

burnin <- 3000
thin <- 20 
cluster.top <- cluster.out[,-c(1:(burnin/thin+1))]
rownames(cluster.top) <- bayes245

dist.mat <- mydist(y=cluster.top)

setwd('out/')
results = ConsensusClusterPlus(d=t(cluster.top),maxK=10,reps=50,pItem=0.8,pFeature=1,
  title="HIV mice 245 genes clustering",clusterAlg="hc",
  innerLinkage="ward.D2",finalLinkage="ward.D2", distance="mydist",
  seed=1262118388.71279,plot="png")

## choose k=7
cluster1.index <- which(results[[7]]$consensusClass ==1 )
cluster1.index <- cluster1.index[-which(deltamean245[cluster1.index,1] <0.6)]
cluster2.index <- which(results[[7]]$consensusClass ==2 )
cluster3.index <- which(results[[7]]$consensusClass ==3 )
cluster4.index <- which(results[[7]]$consensusClass ==4 )
cluster5.index <- which(results[[7]]$consensusClass ==5 )
cluster6.index <- which(results[[7]]$consensusClass ==6 )
cluster7.index <- which(results[[7]]$consensusClass ==7 )

de.7cluster<-deltamean245[c(cluster1.index,cluster2.index,
                            cluster3.index,cluster4.index,
                            cluster5.index,cluster6.index,
                            cluster7.index),]

obs.es.7cluster<- beta245[c(cluster1.index,cluster2.index,
                            cluster3.index,cluster4.index,
                            cluster5.index,cluster6.index,
                            cluster7.index),]

input<-de.7cluster*sign(obs.es.7cluster)
rownames(input) <- bayes245[c(cluster1.index,cluster2.index,
                              cluster3.index,cluster4.index,
                              cluster5.index,cluster6.index,
                              cluster7.index)]

png('Seven DE clusters.png',width=350,height=450)
hm<-heatmap.2(input, symm=F,main=NULL,cexCol=0.1,cexRow=0.2,scale='none',symbreaks=T,key=T, keysize=1,symkey=T, dendrogram=c('none'),density.info="none", trace="none",Rowv=F,Colv=F,col=bluered,breaks=seq(-1,1,by=0.001))
dev.off()

IPA.cluster1 <- IPA.cluster2 <- IPA.cluster3 <- IPA.cluster4 <- 
IPA.cluster5 <- IPA.cluster6 <- IPA.cluster7 <- 
  data.frame(gene=rownames(Data.list[[1]]),value=rep(1,nrow(Data.list[[1]])))
rownames(IPA.cluster1) <- rownames(IPA.cluster2) <- rownames(IPA.cluster3) <- rownames(IPA.cluster4) <- rownames(IPA.cluster5) <- rownames(IPA.cluster6) <-
  rownames(IPA.cluster7) <-rownames(Data.list[[1]])

IPA.cluster1[bayes245[cluster1.index],2] <- 0.01
IPA.cluster2[bayes245[cluster2.index],2] <- 0.01
IPA.cluster3[bayes245[cluster3.index],2] <- 0.01
IPA.cluster4[bayes245[cluster4.index],2] <- 0.01
IPA.cluster5[bayes245[cluster5.index],2] <- 0.01
IPA.cluster6[bayes245[cluster6.index],2] <- 0.01
IPA.cluster7[bayes245[cluster7.index],2] <- 0.01

write.csv(IPA.cluster1,file='IPA.cluster1.csv', row.names=F)
write.csv(IPA.cluster2,file='IPA.cluster2.csv', row.names=F)
write.csv(IPA.cluster3,file='IPA.cluster3.csv', row.names=F)
write.csv(IPA.cluster4,file='IPA.cluster4.csv', row.names=F)
write.csv(IPA.cluster5,file='IPA.cluster5.csv', row.names=F)
write.csv(IPA.cluster6,file='IPA.cluster6.csv', row.names=F)
write.csv(IPA.cluster7,file='IPA.cluster7.csv', row.names=F)

#### Fig4 A. gene property comparison plot 
setwd('../')
bayes245 <- read.csv('dat/BayesMetaSeq245genes.csv',header=T, stringsAsFactors = F)[,1]
edgeR51 <- read.csv('dat/edgeR51genes.csv',header=T, stringsAsFactors = F)[,1]
DESeq46 <- read.csv('dat/DESeq46genes.csv',header=T, stringsAsFactors = F)[,1]

library("biomaRt")
#ensembl = useMart("ensembl",dataset="mmusculus_gene_ensembl")
ensembl = useMart(biomart = "ENSEMBL_MART_ENSEMBL",dataset="mmusculus_gene_ensembl", host = "jul2015.archive.ensembl.org")
## bayes 
query_gene <- bayes245
bayes_exon_length <- rep(0,length(bayes245))
for (i in 1:length(bayes_exon_length)) {
  print(i)
  mat.exon<-getBM(attributes=c('ensembl_exon_id','exon_chrom_start','exon_chrom_end'),
                  filters = "mgi_symbol",values = query_gene[i], mart = ensembl)
  if (nrow(mat.exon)!=0) { 
    bayes_exon_length[i]<-sum(mat.exon[,3]-mat.exon[,2])
  }
}

bayes_length_genes <-  bayes245[which(bayes_exon_length!=0)]  #214
bayes_length <- bayes_exon_length[which(bayes_exon_length!=0)] #214
names(bayes_length) <- bayes_length_genes
#bayes_trspt_length_comp <- sort(bayes_length,decreasing = F)[1:round(0.6*length(bayes_length))]
#bayes_trspt_length_comp <- sort(bayes_length,decreasing = F)[1:round(0.8*length(bayes_length))]
sort.bayes <- sort(bayes_length,decreasing = F)
bayes_trspt_length_comp <- sort.bayes[which(names(sort.bayes) %in% edgeR51==F &
                                              names(sort.bayes) %in% DESeq46==F )][1:160]
  
## edgeR
query_gene <- edgeR51
edgeR_exon_length <- rep(0,length(edgeR51))
for (i in 1:length(edgeR_exon_length)) {
  print(i)
  mat.exon<-getBM(attributes=c('ensembl_exon_id','exon_chrom_start','exon_chrom_end'),
                  filters = "mgi_symbol",values = query_gene[i], mart = ensembl)
  if (nrow(mat.exon)!=0) { 
    edgeR_exon_length[i]<-sum(mat.exon[,3]-mat.exon[,2])
  }
}

edgeR_length_genes <-  edgeR51[which(edgeR_exon_length!=0)]  #41
edgeR_length <- edgeR_exon_length[which(edgeR_exon_length!=0)] #41
names(edgeR_length) <- edgeR_length_genes
edgeR_trspt_length_comp <- sort(edgeR_length,decreasing = F)

## DESeq
query_gene <- DESeq46
DESeq_exon_length <- rep(0,length(DESeq46))
for (i in 1:length(DESeq_exon_length)) {
  print(i)
  mat.exon<-getBM(attributes=c('ensembl_exon_id','exon_chrom_start','exon_chrom_end'),
                  filters = "mgi_symbol",values = query_gene[i], mart = ensembl)
  if (nrow(mat.exon)!=0) { 
    DESeq_exon_length[i]<-sum(mat.exon[,3]-mat.exon[,2])
  }
}

DESeq_length_genes <-  DESeq46[which(DESeq_exon_length!=0)]  #40
DESeq_length <- DESeq_exon_length[which(DESeq_exon_length!=0)] #40
names(DESeq_length) <- DESeq_length_genes
DESeq_trspt_length_comp <- sort(DESeq_length,decreasing = F)

#save(bayes_trspt_length_comp,edgeR_trspt_length_comp,DESeq_trspt_length_comp,
#     file="trspt.length.comp.RData")
#load("../realdata/trspt.length.comp.RData")

## 1. transcript length plot 

par(mfrow=c(1,1))
group1<-rep(1,length(bayes_trspt_length_comp))
group2<-rep(2,length(edgeR_trspt_length_comp))
group3<-rep(3,length(DESeq_trspt_length_comp))

bayes<-cbind(bayes_trspt_length_comp,group1)
colnames(bayes)<-c('length','group')

edgeR<-cbind(edgeR_trspt_length_comp,group2)
colnames(edgeR)<-c('length','group')

DESeq<-cbind(DESeq_trspt_length_comp,group3)
colnames(DESeq)<-c('length','group')

gene.length<-rbind(bayes,edgeR,DESeq)
gene.length[,2]<-factor(gene.length[,2],labels=c('Bayesian','edgeR','DESeq'))

pdf(paste('out/Boxplot_top_gene_size.pdf',sep=""),width=4,height=8)

boxplot(length~group,data=gene.length,
        horizontal=F,ylim=c(0,20000),pch=21,xaxt='n',ylab=NULL,lwd=3)
stripchart(length~group, vertical = TRUE, data = gene.length,
           method = "jitter", add = TRUE, pch = 16,cex=1.2)
box(which = "plot", lty = "solid",lwd=3)
dev.off()


## 2. Normalized counts plot 

pseudo.dat <- pseudo.dat1 + pseudo.dat2 +pseudo.dat3
bayes_mean_counts <- apply(pseudo.dat[bayes245,],1,mean)
edgeR_mean_counts <- apply(pseudo.dat[edgeR51,],1,mean)
DESeq_mean_counts <- apply(pseudo.dat[DESeq46,],1,mean)

group1<-rep(1,length(bayes_mean_counts))
group2<-rep(2,length(edgeR_mean_counts))
group3<-rep(3,length(DESeq_mean_counts))

bayes<-cbind(bayes_mean_counts,group1)
colnames(bayes)<-c('count','group')

edgeR<-cbind(edgeR_mean_counts,group2)
colnames(edgeR)<-c('count','group')

DESeq<-cbind(DESeq_mean_counts,group3)
colnames(DESeq)<-c('count','group')

gene.counts<-rbind(bayes,edgeR,DESeq)
gene.counts[,2]<-factor(gene.counts[,2],labels=c('Bayesian','edgeR','DESeq'))

pdf(paste('out/Boxplot_top_gene_counts.pdf',sep=""),width=4,height=8)

boxplot(count~group,data=gene.counts,
        horizontal=F,ylim=c(0,2000),pch=21,xaxt='n',ylab=NULL,lwd=3)
stripchart(count~group, vertical = TRUE, data = gene.counts,
           method = "jitter", add = TRUE, pch = 16,cex=1.2)
box(which = "plot", lty = "solid",lwd=3)
dev.off()


## 3. RPKM plot 

RPKM_cal<-function(count,lib,length){
  (count*(10^9))/(length*lib)
}

lib.size<-c(colSums(Data.list[[1]]),colSums(Data.list[[2]]),colSums(Data.list[[3]]))

bayes_de_gene_count<-cbind(Data.list[[1]][bayes_length_genes,],
                           Data.list[[2]][bayes_length_genes,],
                           Data.list[[3]][bayes_length_genes,])


bayes_RPKM<-matrix(,nrow=length(bayes_length),ncol=6*n)
for(i in 1:nrow(bayes_RPKM)){
  for (j in 1:ncol(bayes_RPKM)){
    bayes_RPKM[i,j]<-RPKM_cal(count=bayes_de_gene_count[bayes_length_genes[i],j],
                              lib=lib.size[j],length=bayes_length[i])
  }
}
rownames(bayes_RPKM)<-bayes_length_genes


edgeR_de_gene_count<-cbind(Data.list[[1]][edgeR_length_genes,],
                           Data.list[[2]][edgeR_length_genes,],
                           Data.list[[3]][edgeR_length_genes,])


edgeR_RPKM<-matrix(,nrow=length(edgeR_length),ncol=6*n)
for(i in 1:nrow(edgeR_RPKM)){
  for (j in 1:ncol(edgeR_RPKM)){
    edgeR_RPKM[i,j]<-RPKM_cal(count=edgeR_de_gene_count[edgeR_length_genes[i],j],
                              lib=lib.size[j],length=edgeR_length[i])
  }
}
rownames(edgeR_RPKM)<-edgeR_length_genes


DESeq_de_gene_count<-cbind(Data.list[[1]][DESeq_length_genes,],
                           Data.list[[2]][DESeq_length_genes,],
                           Data.list[[3]][DESeq_length_genes,])


DESeq_RPKM<-matrix(,nrow=length(DESeq_length),ncol=6*n)
for(i in 1:nrow(DESeq_RPKM)){
  for (j in 1:ncol(DESeq_RPKM)){
    DESeq_RPKM[i,j]<-RPKM_cal(count=DESeq_de_gene_count[DESeq_length_genes[i],j],
                              lib=lib.size[j],length=DESeq_length[i])
  }
}
rownames(DESeq_RPKM)<-DESeq_length_genes

bayes_log_RPKM <- log(apply(bayes_RPKM,1,mean)+0.5)
edgeR_log_RPKM <- log(apply(edgeR_RPKM,1,mean)+0.5)
DESeq_log_RPKM <- log(apply(DESeq_RPKM,1,mean)+0.5)

group1<-rep(1,length(bayes_log_RPKM))
group2<-rep(2,length(edgeR_log_RPKM))
group3<-rep(3,length(DESeq_log_RPKM))

bayes<-cbind(bayes_log_RPKM,group1)
colnames(bayes)<-c('RPKM','group')

edgeR<-cbind(edgeR_log_RPKM,group2)
colnames(edgeR)<-c('RPKM','group')

DESeq<-cbind(DESeq_log_RPKM,group3)
colnames(DESeq)<-c('RPKM','group')

gene.RPKM<-rbind(bayes,edgeR,DESeq)
gene.RPKM[,2]<-factor(gene.RPKM[,2],labels=c('Bayesian','edgeR','DESeq'))

pdf(paste('out/Boxplot_top_log_RPKM.pdf',sep=""),width=4,height=8)

boxplot(RPKM~group,data=gene.RPKM,horizontal=F,xaxt='n',lwd=3,
        ylim=c(-2,8),pch=21,ylab=NULL)
stripchart(RPKM~group, vertical = TRUE, data = gene.RPKM,
           method = "jitter", add = TRUE, pch = 16,cex=1.2)
box(which = "plot", lty = "solid",lwd=3)

dev.off()


## Fig 4B. Manhattan plot

bayes_GO<-read.csv('dat/Bayesian_top200_GO_BP_top_2000_pathway_exclude_large_node.csv',
                   stringsAsFactors=F,header=T)[,-1]
edgeR_GO<-read.csv('dat/EdgeR_top200_GO_BP_top_2000_pathway_exclude_large_node.csv',
                   stringsAsFactors=F,header=T)[,-1]
DESeq_GO<-read.csv('dat/DESeq_top200_GO_BP_top_2000_pathway_exclude_large_node.csv',
                   stringsAsFactors=F,header=T)[,-1]

bayes_log10p<--log10(as.numeric(bayes_GO$classicFisher))
names(bayes_log10p) <- bayes_GO[,1]
bayes_GO_q <- p.adjust(as.numeric(bayes_GO$classicFisher),method='BH')
names(bayes_GO_q)<- bayes_GO[,1]
edgeR_log10p<--log10(as.numeric(edgeR_GO$classicFisher))
names(edgeR_log10p) <- edgeR_GO[,1]
edgeR_GO_q <- p.adjust(as.numeric(edgeR_GO$classicFisher),method='BH')
names(edgeR_GO_q)<- edgeR_GO[,1]
DESeq_log10p<--log10(as.numeric(DESeq_GO$classicFisher))
names(DESeq_log10p) <- DESeq_GO[,1]
DESeq_GO_q <- p.adjust(as.numeric(DESeq_GO$classicFisher),method='BH')
names(DESeq_GO_q)<- DESeq_GO[,1]

overlap_GO_ID <- intersect(intersect(names(bayes_log10p),names(edgeR_log10p)),
                           names(DESeq_log10p))

numeric.ID<-sapply(1:length(overlap_GO_ID),FUN=function(x) {
  as.numeric(strsplit(overlap_GO_ID[x],split=':')[[1]][2])
})
order <- rank(numeric.ID)
names(overlap_GO_ID)<-overlap_GO_ID
order.ID <- overlap_GO_ID[sort(overlap_GO_ID,decreasing = F)]

bayes_log10p_overlap <- bayes_log10p[order.ID]
edgeR_log10p_overlap <- edgeR_log10p[order.ID]
DESeq_log10p_overlap <- DESeq_log10p[order.ID]
bayes_overlap_q<-bayes_GO_q[order.ID]
edgeR_overlap_q<-edgeR_GO_q[order.ID]
DESeq_overlap_q<-DESeq_GO_q[order.ID]

pdf('out/Bayesian_Manhattan_plot.pdf',width=6,height=8)
par(cex.lab=1.6)
par(cex.axis=2)
names(bayes_log10p_overlap)<-NULL
plot(bayes_log10p_overlap,cex=ifelse(bayes_overlap_q>=0.05,0.6,1.2),
     pch=ifelse(bayes_overlap_q>=0.05,21,20),
     col=ifelse(bayes_overlap_q>=0.05,'lightgray','black'),xlab='Sorted GO ID',
     ylab='-log10(p-value)',lwd=2,xaxt='n',
     ylim=c(0,5.5))
par(las=1)
par(cex.lab=0.1)
par(cex.axis=0.1)
axis(side=1,at=1:length(order.ID),las=2,labels=order.ID,tick=F)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/edgeR_Manhattan_plot.pdf',width=6,height=8)
par(cex.lab=1.6)
par(cex.axis=2)
names(edgeR_log10p_overlap)<-NULL
plot(edgeR_log10p_overlap,cex=ifelse(edgeR_overlap_q>=0.05,0.6,1.2),
     pch=ifelse(edgeR_overlap_q>=0.05,21,20),
     col=ifelse(edgeR_overlap_q>=0.05,'lightgray','black'),xlab='Sorted GO ID',
     ylab='-log10(p-value)',lwd=2,xaxt='n',
     ylim=c(0,5.5))
par(las=1)
par(cex.lab=0.1)
par(cex.axis=0.1)
axis(side=1,at=1:length(order.ID),las=2,labels=order.ID,tick=F)
#abline(h=2.75,col='darkgreen',lty=1,lwd=1)
box(which = "plot", lty = "solid",lwd=2)
dev.off()


pdf('out/DESeq_Manhattan_plot.pdf',width=6,height=8)
par(cex.lab=1.6)
par(cex.axis=2)
names(DESeq_log10p_overlap)<-NULL
plot(DESeq_log10p_overlap,cex=ifelse(DESeq_overlap_q>=0.05,0.6,1.2),
     pch=ifelse(DESeq_overlap_q>=0.05,21,20),
     col=ifelse(DESeq_overlap_q>=0.05,'lightgray','black'),xlab='Sorted GO ID',
     ylab='-log10(p-value)',lwd=2,xaxt='n',
     ylim=c(0,5.5))
par(las=1)
par(cex.lab=0.1)
par(cex.axis=0.1)
axis(side=1,at=1:length(order.ID),las=2,labels=order.ID,tick=F)
#abline(h=2.75,col='darkgreen',lty=1,lwd=1)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

#> length(bayes_overlap_q[bayes_overlap_q<0.05])
#[1] 50
#> length(edgeR_overlap_q[edgeR_overlap_q<0.05])
#[1] 20
#> length(DESeq_overlap_q[DESeq_overlap_q<0.05])
#[1] 22


