###################################################
## Reproduce sim part ############################
### 16/10/02 ######################################

library("gplots")
library("WGCNA")
library(edgeR)
library(DESeq)
library(MASS)
library(ConsensusClusterPlus)
library(flux)
source("src/PowerROC161002.R")

####### Sim IA K=2

source("src/MCMC.StoreAll161002")
load("dat/SimIA_K2_Data.rda")
G <- 1000
K <- 2
N <- ncol(count[[1]])
Data.list <- count
X.list <- replicate(K,c(rep(1,N/2),rep(0,N/2)) , simplify=F)

lambda.mean<-0
lambda.var<-10
eta.mean <- -7
eta.var<- 10
m.mean <- -2
m.var <- 10

init <- Initialize(Data.list=Data.list,X.list=X.list,
                   lambda.mean=lambda.mean,lambda.var=lambda.var,
                   eta.mean=eta.mean,eta.var=eta.var,
                   m.mean=m.mean,m.var=m.var,seed=12345)

iteration<- 10000
store <- Store(Data.list=Data.list,X.list=X.list,iteration=iteration)                        

MCMC.out <- MCMCRun(Data.list=Data.list,X.list=X.list,Init.value=init,
                    Store.value = store,iteration=iteration,
                    lambda.mean=lambda.mean, lambda.var=lambda.var, 
                    eta.mean=eta.mean, eta.var=eta.var, 
                    m.mean=m.mean, m.var=m.var, seed=12345) 

burnin<-3000

### estimate
beta.mean <- apply(MCMC.out[['Beta']][,-c(1:burnin)],1,mean)
beta.mat <- matrix(beta.mean,byrow=T,nrow=G,ncol=K)
beta.mat.de <- beta.mat[1:200,]
mean(apply(beta.mat.de,1,mean)[which(apply(beta.mat.de,1,mean)>0)])
#[1] 1.213147
sd(apply(beta.mat.de,1,mean)[which(apply(beta.mat.de,1,mean)>0)])
#[1] 0.4964254
mean(apply(beta.mat.de,1,mean)[which(apply(beta.mat.de,1,mean)<0)])
#[1] -1.246523
sd(apply(beta.mat.de,1,mean)[which(apply(beta.mat.de,1,mean)<0)])
#[1] 0.5904093
mean(apply(beta.mat[201:1000,],1,mean))
#[1] -0.008242327
sd(apply(beta.mat[201:1000,],1,mean))
#[1] 0.4163529

alpha.mean <- apply(MCMC.out[['Alpha']][,-c(1:burnin)],1,mean)
alpha.mat <- matrix(alpha.mean,byrow=T,nrow=G,ncol=K)
median(apply(alpha.mat[c(1:100,201:600),],1,mean))
#[1] -7.042063
sd(apply(alpha.mat[c(1:100,201:600),],1,mean))
#[1] 1.314626
median(apply(alpha.mat[c(101:200),],1,mean))
#[1] -11.10613
sd(apply(alpha.mat[c(101:200),],1,mean))
#[1] 0.7804108

### traceplot

beta<-MCMC.out[['Beta']]
lambda<-MCMC.out[['Lambda']]
alpha<-MCMC.out[['Alpha']]
eta<-MCMC.out[['Eta']]
phi<-MCMC.out[['LogPhi']]
m<-MCMC.out[['M']]
K <- 2
ind <- 3
trace.mat <- list(beta[1+(ind-1)*K,],beta[2+(ind-1)*K,],lambda[ind,],
                  alpha[1+(ind-1)*K,],alpha[2+(ind-1)*K,],eta[ind,],
                  phi[1+(ind-1)*K,],phi[2+(ind-1)*K,],m[ind,])
sampleNames<-c(expression(beta),expression(beta),expression(lambda),
               expression(alpha),expression(alpha),expression(eta),
               expression(phi),expression(phi),expression(m))

parRow=3
parCol=3
pdf('out/traceplots.pdf',width=10,height=8)
par(mfrow = c(parRow,parCol))
for (i in 1:length(trace.mat)) {
  plot(trace.mat[[i]],xlab='iteration',type='l',ylab='',main=sampleNames[i])  
}

dev.off()

### power and ROC 

fisher<-function(x) {
  f<-sum(-2*log(x))
  1-pchisq(f,df=2*length(x))
}

delta<-MCMC.out[["Delta"]]
delta.mean<-apply(delta[,-c(1:burnin)],1,mean)
delta.mat<-matrix(delta.mean,nrow=G,ncol=K,byrow=T)

beta<-MCMC.out[["Beta"]]
beta.mean<-apply(beta[,-c(1:burnin)],1,mean)
beta.mat<-matrix(beta.mean,nrow=G,ncol=K,byrow=T)

n<-5
X<-c(rep(1,n),rep(0,n))
group=factor(X)

d=DGEList(counts=count[[1]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value1<-et$table[,3]
d=DGEList(counts=count[[2]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value2<-et$table[,3]

edge.q<-cbind(p_value1,p_value2)

condition=factor(c(rep('A',n),rep('B',n)))
cds1 = newCountDataSet( count[[1]], condition )
cds1 = estimateSizeFactors( cds1 )
cds1 = estimateDispersions( cds1, fitType = c("local") )
res1 = nbinomTest( cds1, "A", "B" )
p1 = res1$pval
cds2 = newCountDataSet( count[[2]], condition )
cds2 = estimateSizeFactors( cds2 )
cds2 = estimateDispersions( cds2, fitType = c("local") )
res2 = nbinomTest( cds2, "A", "B" )
p2 = res2$pval

DESeq.q<-cbind(p1,p2)

rownames(delta.mat)<-paste('gene',1:1000,sep='')
rownames(edge.q)<-paste('gene',1:1000,sep='')
rownames(DESeq.q)<-paste('gene',1:1000,sep='')
p_fisher_edgeR <- apply(edge.q,1,fisher)
p_fisher_DESeq <- apply(DESeq.q,1,fisher)
#q_fisher_edgeR<-p.adjust(apply(edge.q,1,fisher),method='BH')
#q_fisher_DESeq<-p.adjust(apply(DESeq.q,1,fisher),method='BH')

ind.all<-1:200
ind.L<-101:200
ind.H<-1:100
not.ind.all<-201:1000
not.ind.L<-601:1000
not.ind.H<-201:600

top<-seq(2,100,by=2)
delta.cut <- seq(0,1,0.01)
all<-seq(1,1000,10)
all.L<- all.H<- seq(1,500,5)

### For Low mean region: 101:200, 601:1000

delta.mat.L<-delta.mat[c(ind.L,not.ind.L),]
p_fisher_edgeR.L<-p_fisher_edgeR[c(ind.L,not.ind.L)]
p_fisher_DESeq.L<-p_fisher_DESeq[c(ind.L,not.ind.L)]

### For High mean region: 1:100, 201:600

delta.mat.H<-delta.mat[c(ind.H,not.ind.H),]
p_fisher_edgeR.H<-p_fisher_edgeR[c(ind.H,not.ind.H)]
p_fisher_DESeq.H<-p_fisher_DESeq[c(ind.H,not.ind.H)]

attr(delta.mat.L,"method") <- attr(delta.mat.H,"method") <- "Bayes"
attr(delta.mat.L,"study") <- attr(delta.mat.H,"study") <- 2
attr(delta.mat.L,"type") <- attr(delta.mat.H,"type") <- "homo"
attr(delta.mat.L,"region") <- "low"
attr(delta.mat.H,"region") <- "high"

attr(p_fisher_edgeR.L,"method") <- attr(p_fisher_edgeR.H,"method") <- attr(p_fisher_DESeq.L,"method") <- attr(p_fisher_DESeq.H,"method") <- "Fisher"
attr(p_fisher_edgeR.L,"study") <- attr(p_fisher_edgeR.H,"study") <- attr(p_fisher_DESeq.L,"study") <- attr(p_fisher_DESeq.H,"study") <- 2
attr(p_fisher_edgeR.L,"type") <- attr(p_fisher_edgeR.H,"type") <- attr(p_fisher_DESeq.L,"type") <- attr(p_fisher_DESeq.H,"type") <- "homo"
attr(p_fisher_edgeR.L,"region") <- attr(p_fisher_DESeq.L,"region")  <- "low"
attr(p_fisher_edgeR.H,"region") <- attr(p_fisher_DESeq.H,"region")  <- "high"

(tp.num.bayes.meta.L<-sapply(top,Power,input=delta.mat.L, ind=ind.L))
(tp.num.edgeR.fisher.L<-sapply(top,Power,input=p_fisher_edgeR.L,ind=ind.L))
(tp.num.DESeq.fisher.L<-sapply(top,Power,input=p_fisher_DESeq.L,ind=ind.L))

(sens.bayes.meta.L<-sapply(delta.cut,Sens,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(spec.bayes.meta.L<-sapply(delta.cut,Spec,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(auc.bayes.L <- auc(sens.bayes.meta.L,spec.bayes.meta.L))

(sens.edgeR.fisher.L<-sapply(all.L,Sens,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(spec.edgeR.fisher.L<-sapply(all.L,Spec,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(auc.edgeR.L <- auc(sens.edgeR.fisher.L,spec.edgeR.fisher.L))

(sens.DESeq.fisher.L<-sapply(all.L,Sens,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(spec.DESeq.fisher.L<-sapply(all.L,Spec,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(auc.DESeq.L <- auc(sens.DESeq.fisher.L,spec.DESeq.fisher.L))

pdf('out/sim.powerROC/SimIA.K2.Low.Power.pdf')
par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.L,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.L,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.L,cex=1,lty=3,lwd=8)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIA.K2.Low.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.L,sens.bayes.meta.L,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.L,sens.edgeR.fisher.L,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.L,sens.DESeq.fisher.L,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.L,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.L,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.L,digits=2),sep=""),cex=2.5,font=2)
dev.off()

(tp.num.bayes.meta.H<-sapply(top,Power,input=delta.mat.H, ind=ind.H))
(tp.num.edgeR.fisher.H<-sapply(top,Power,input=p_fisher_edgeR.H,ind=ind.H))
(tp.num.DESeq.fisher.H<-sapply(top,Power,input=p_fisher_DESeq.H,ind=ind.H))

(sens.bayes.meta.H<-sapply(delta.cut,Sens,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(spec.bayes.meta.H<-sapply(delta.cut,Spec,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(auc.bayes.H <- auc(sens.bayes.meta.H,spec.bayes.meta.H))

(sens.edgeR.fisher.H<-sapply(all.H,Sens,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(spec.edgeR.fisher.H<-sapply(all.H,Spec,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(auc.edgeR.H <- auc(sens.edgeR.fisher.H,spec.edgeR.fisher.H))

(sens.DESeq.fisher.H<-sapply(all.H,Sens,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(spec.DESeq.fisher.H<-sapply(all.H,Spec,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(auc.DESeq.H <- auc(sens.DESeq.fisher.H,spec.DESeq.fisher.H))

pdf('out/sim.powerROC/SimIA.K2.High.Power.pdf')
par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.H,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.H,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.H,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIA.K2.High.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.H,sens.bayes.meta.H,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.H,sens.edgeR.fisher.H,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.H,sens.DESeq.fisher.H,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.H,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.H,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.H,digits=2),sep=""),cex=2.5,font=2)

dev.off()


########## Sim IA K=5

source("src/MCMC161002.R")

load("dat/SimIA_K5_Data.rda")
G <- 1000
K <- 5
N <- ncol(count[[1]])
Data.list <- count
X.list <- replicate(K,c(rep(1,N/2),rep(0,N/2)) , simplify=F)

lambda.mean<-0
lambda.var<-10
eta.mean <- -7
eta.var<- 10
m.mean <- -2
m.var <- 10

init <- Initialize(Data.list=Data.list,X.list=X.list,
                   lambda.mean=lambda.mean,lambda.var=lambda.var,
                   eta.mean=eta.mean,eta.var=eta.var,
                   m.mean=m.mean,m.var=m.var,seed=12345)

iteration<- 10000
store <- Store(Data.list=Data.list,X.list=X.list,iteration=iteration)                        

MCMC.out <- MCMCRun(Data.list=Data.list,X.list=X.list,Init.value=init,
                    Store.value = store,iteration=iteration,
                    lambda.mean=lambda.mean, lambda.var=lambda.var, 
                    eta.mean=eta.mean, eta.var=eta.var, 
                    m.mean=m.mean, m.var=m.var, seed=12345) 

burnin<-3000

### power and ROC 

fisher<-function(x) {
  f<-sum(-2*log(x))
  1-pchisq(f,df=2*length(x))
}

delta<-MCMC.out[["Delta"]]
delta.mean<-apply(delta[,-c(1:burnin)],1,mean)
delta.mat<-matrix(delta.mean,nrow=G,ncol=K,byrow=T)

beta<-MCMC.out[["Beta"]]
beta.mean<-apply(beta[,-c(1:burnin)],1,mean)
beta.mat<-matrix(beta.mean,nrow=G,ncol=K,byrow=T)

n<-5
X<-c(rep(1,n),rep(0,n))

group=factor(X)
d=DGEList(counts=count[[1]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value1<-et$table[,3]

d=DGEList(counts=count[[2]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value2<-et$table[,3]

d=DGEList(counts=count[[3]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value3<-et$table[,3]

d=DGEList(counts=count[[4]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value4<-et$table[,3]

d=DGEList(counts=count[[5]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value5<-et$table[,3]

edge.q<-cbind(p_value1,p_value2,p_value3,p_value4,p_value5)

condition=factor(c(rep('A',n),rep('B',n)))
cds1 = newCountDataSet( count[[1]], condition )
cds1 = estimateSizeFactors( cds1 )
cds1 = estimateDispersions( cds1, fitType = c("local") )
res1 = nbinomTest( cds1, "A", "B" )
p1 = res1$pval

cds2 = newCountDataSet( count[[2]], condition )
cds2 = estimateSizeFactors( cds2 )
cds2 = estimateDispersions( cds2, fitType = c("local") )
res2 = nbinomTest( cds2, "A", "B" )
p2 = res2$pval

cds3 = newCountDataSet( count[[3]], condition )
cds3 = estimateSizeFactors( cds3 )
cds3 = estimateDispersions( cds3, fitType = c("local") )
res3 = nbinomTest( cds3, "A", "B" )
p3 = res3$pval

cds4 = newCountDataSet( count[[4]], condition )
cds4 = estimateSizeFactors( cds4 )
cds4 = estimateDispersions( cds4, fitType = c("local") )
res4 = nbinomTest( cds4, "A", "B" )
p4 = res4$pval

cds5 = newCountDataSet( count[[5]], condition )
cds5 = estimateSizeFactors( cds5 )
cds5 = estimateDispersions( cds5, fitType = c("local") )
res5 = nbinomTest( cds5, "A", "B" )
p5 = res5$pval

DESeq.q<-cbind(p1,p2,p3,p4,p5)

rownames(delta.mat)<-paste('gene',1:1000,sep='')
rownames(edge.q)<-paste('gene',1:1000,sep='')
rownames(DESeq.q)<-paste('gene',1:1000,sep='')

p_fisher_edgeR <- apply(edge.q,1,fisher)
p_fisher_DESeq <- apply(DESeq.q,1,fisher)
#q_fisher_edgeR<-p.adjust(apply(edge.q,1,fisher),method='BH')
#q_fisher_DESeq<-p.adjust(apply(DESeq.q,1,fisher),method='BH')

ind.all<-1:200
ind.L<-101:200
ind.H<-1:100
not.ind.all<-201:1000
not.ind.L<-601:1000
not.ind.H<-201:600

top<-seq(2,100,by=2)
delta.cut <- seq(0,1,0.01)
all<-seq(1,1000,10)
all.L<- all.H<- seq(1,500,5)

### For Low mean region: 101:200, 601:1000

delta.mat.L<-delta.mat[c(ind.L,not.ind.L),]
p_fisher_edgeR.L<-p_fisher_edgeR[c(ind.L,not.ind.L)]
p_fisher_DESeq.L<-p_fisher_DESeq[c(ind.L,not.ind.L)]

### For High mean region: 1:100, 201:600

delta.mat.H<-delta.mat[c(ind.H,not.ind.H),]
p_fisher_edgeR.H<-p_fisher_edgeR[c(ind.H,not.ind.H)]
p_fisher_DESeq.H<-p_fisher_DESeq[c(ind.H,not.ind.H)]

attr(delta.mat.L,"method") <- attr(delta.mat.H,"method") <- "Bayes"
attr(delta.mat.L,"study") <- attr(delta.mat.H,"study") <- 5
attr(delta.mat.L,"type") <- attr(delta.mat.H,"type") <- "homo"
attr(delta.mat.L,"region") <- "low"
attr(delta.mat.H,"region") <- "high"

attr(p_fisher_edgeR.L,"method") <- attr(p_fisher_edgeR.H,"method") <- attr(p_fisher_DESeq.L,"method") <- attr(p_fisher_DESeq.H,"method") <- "Fisher"
attr(p_fisher_edgeR.L,"study") <- attr(p_fisher_edgeR.H,"study") <- attr(p_fisher_DESeq.L,"study") <- attr(p_fisher_DESeq.H,"study") <- 5
attr(p_fisher_edgeR.L,"type") <- attr(p_fisher_edgeR.H,"type") <- attr(p_fisher_DESeq.L,"type") <- attr(p_fisher_DESeq.H,"type") <- "homo"
attr(p_fisher_edgeR.L,"region") <- attr(p_fisher_DESeq.L,"region")  <- "low"
attr(p_fisher_edgeR.H,"region") <- attr(p_fisher_DESeq.H,"region")  <- "high"

(tp.num.bayes.meta.L<-sapply(top,Power,input=delta.mat.L, ind=ind.L))
(tp.num.edgeR.fisher.L<-sapply(top,Power,input=p_fisher_edgeR.L,ind=ind.L))
(tp.num.DESeq.fisher.L<-sapply(top,Power,input=p_fisher_DESeq.L,ind=ind.L))

(sens.bayes.meta.L<-sapply(delta.cut,Sens,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(spec.bayes.meta.L<-sapply(delta.cut,Spec,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(auc.bayes.L <- auc(sens.bayes.meta.L,spec.bayes.meta.L))

(sens.edgeR.fisher.L<-sapply(all.L,Sens,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(spec.edgeR.fisher.L<-sapply(all.L,Spec,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(auc.edgeR.L <- auc(sens.edgeR.fisher.L,spec.edgeR.fisher.L))

(sens.DESeq.fisher.L<-sapply(all.L,Sens,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(spec.DESeq.fisher.L<-sapply(all.L,Spec,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(auc.DESeq.L <- auc(sens.DESeq.fisher.L,spec.DESeq.fisher.L))

pdf('out/sim.powerROC/SimIA.K5.Low.Power.pdf')

par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.L,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.L,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.L,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIA.K5.Low.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.L,sens.bayes.meta.L,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.L,sens.edgeR.fisher.L,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.L,sens.DESeq.fisher.L,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.L,digits=2),sep=''),cex=2.5,font=2)

dev.off()

(tp.num.bayes.meta.H<-sapply(top,Power,input=delta.mat.H, ind=ind.H))
(tp.num.edgeR.fisher.H<-sapply(top,Power,input=p_fisher_edgeR.H,ind=ind.H))
(tp.num.DESeq.fisher.H<-sapply(top,Power,input=p_fisher_DESeq.H,ind=ind.H))

(sens.bayes.meta.H<-sapply(delta.cut,Sens,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(spec.bayes.meta.H<-sapply(delta.cut,Spec,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(auc.bayes.H <- auc(sens.bayes.meta.H,spec.bayes.meta.H))

(sens.edgeR.fisher.H<-sapply(all.H,Sens,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(spec.edgeR.fisher.H<-sapply(all.H,Spec,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(auc.edgeR.H <- auc(sens.edgeR.fisher.H,spec.edgeR.fisher.H))

(sens.DESeq.fisher.H<-sapply(all.H,Sens,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(spec.DESeq.fisher.H<-sapply(all.H,Spec,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(auc.DESeq.H <- auc(sens.DESeq.fisher.H,spec.DESeq.fisher.H))

pdf('out/sim.powerROC/SimIA.K5.High.Power.pdf')

par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.H,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.H,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.H,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIA.K5.High.ROC.pdf')

par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.H,sens.bayes.meta.H,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.H,sens.edgeR.fisher.H,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.H,sens.DESeq.fisher.H,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.H,digits=2),sep=''),cex=2.5,font=2)

dev.off()

########## Sim IB K=2

load("dat/SimIB_K2_Data.rda")
G <- 1000
K <- 2
N <- ncol(count[[1]])
Data.list <- count
X.list <- replicate(K,c(rep(1,N/2),rep(0,N/2)) , simplify=F)

lambda.mean<-0
lambda.var<-10
eta.mean <- -7
eta.var<- 10
m.mean <- -2
m.var <- 10

init <- Initialize(Data.list=Data.list,X.list=X.list,
                   lambda.mean=lambda.mean,lambda.var=lambda.var,
                   eta.mean=eta.mean,eta.var=eta.var,
                   m.mean=m.mean,m.var=m.var,seed=12345)

iteration<- 10000
store <- Store(Data.list=Data.list,X.list=X.list,iteration=iteration)                        

MCMC.out <- MCMCRun(Data.list=Data.list,X.list=X.list,Init.value=init,
                    Store.value = store,iteration=iteration,
                    lambda.mean=lambda.mean, lambda.var=lambda.var, 
                    eta.mean=eta.mean, eta.var=eta.var, 
                    m.mean=m.mean, m.var=m.var, seed=12345) 

burnin <- 3000


### power and ROC 

fisher<-function(x) {
  f<-sum(-2*log(x))
  1-pchisq(f,df=2*length(x))
}

delta<-MCMC.out[["Delta"]]
delta.mean<-apply(delta[,-c(1:burnin)],1,mean)
delta.mat<-matrix(delta.mean,nrow=G,ncol=K,byrow=T)

beta<-MCMC.out[["Beta"]]
beta.mean<-apply(beta[,-c(1:burnin)],1,mean)
beta.mat<-matrix(beta.mean,nrow=G,ncol=K,byrow=T)

n<-5
X<-c(rep(1,n),rep(0,n))
group=factor(X)

d=DGEList(counts=count[[1]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value1<-et$table[,3]
d=DGEList(counts=count[[2]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value2<-et$table[,3]

edge.q<-cbind(p_value1,p_value2)

condition=factor(c(rep('A',n),rep('B',n)))
cds1 = newCountDataSet( count[[1]], condition )
cds1 = estimateSizeFactors( cds1 )
cds1 = estimateDispersions( cds1, fitType = c("local") )
res1 = nbinomTest( cds1, "A", "B" )
p1 = res1$pval
cds2 = newCountDataSet( count[[2]], condition )
cds2 = estimateSizeFactors( cds2 )
cds2 = estimateDispersions( cds2, fitType = c("local") )
res2 = nbinomTest( cds2, "A", "B" )
p2 = res2$pval

DESeq.q<-cbind(p1,p2)

rownames(delta.mat)<-paste('gene',1:1000,sep='')
rownames(edge.q)<-paste('gene',1:1000,sep='')
rownames(DESeq.q)<-paste('gene',1:1000,sep='')
p_fisher_edgeR <- apply(edge.q,1,fisher)
p_fisher_DESeq <- apply(DESeq.q,1,fisher)
#q_fisher_edgeR<-p.adjust(apply(edge.q,1,fisher),method='BH')
#q_fisher_DESeq<-p.adjust(apply(DESeq.q,1,fisher),method='BH')

ind.all<-1:200
ind.L<-101:200
ind.H<-1:100
not.ind.all<-201:1000
not.ind.L<-601:1000
not.ind.H<-201:600

top<-seq(2,100,by=2)
delta.cut <- seq(0,1,0.01)
all<-seq(1,1000,10)
all.L<- all.H<- seq(1,500,5)

### For Low mean region: 101:200, 601:1000

delta.mat.L<-delta.mat[c(ind.L,not.ind.L),]
p_fisher_edgeR.L<-p_fisher_edgeR[c(ind.L,not.ind.L)]
p_fisher_DESeq.L<-p_fisher_DESeq[c(ind.L,not.ind.L)]

### For High mean region: 1:100, 201:600

delta.mat.H<-delta.mat[c(ind.H,not.ind.H),]
p_fisher_edgeR.H<-p_fisher_edgeR[c(ind.H,not.ind.H)]
p_fisher_DESeq.H<-p_fisher_DESeq[c(ind.H,not.ind.H)]

attr(delta.mat.L,"method") <- attr(delta.mat.H,"method") <- "Bayes"
attr(delta.mat.L,"study") <- attr(delta.mat.H,"study") <- 2
attr(delta.mat.L,"type") <- attr(delta.mat.H,"type") <- "homo"
attr(delta.mat.L,"region") <- "low"
attr(delta.mat.H,"region") <- "high"

attr(p_fisher_edgeR.L,"method") <- attr(p_fisher_edgeR.H,"method") <- attr(p_fisher_DESeq.L,"method") <- attr(p_fisher_DESeq.H,"method") <- "Fisher"
attr(p_fisher_edgeR.L,"study") <- attr(p_fisher_edgeR.H,"study") <- attr(p_fisher_DESeq.L,"study") <- attr(p_fisher_DESeq.H,"study") <- 2
attr(p_fisher_edgeR.L,"type") <- attr(p_fisher_edgeR.H,"type") <- attr(p_fisher_DESeq.L,"type") <- attr(p_fisher_DESeq.H,"type") <- "homo"
attr(p_fisher_edgeR.L,"region") <- attr(p_fisher_DESeq.L,"region")  <- "low"
attr(p_fisher_edgeR.H,"region") <- attr(p_fisher_DESeq.H,"region")  <- "high"

(tp.num.bayes.meta.L<-sapply(top,Power,input=delta.mat.L, ind=ind.L))
(tp.num.edgeR.fisher.L<-sapply(top,Power,input=p_fisher_edgeR.L,ind=ind.L))
(tp.num.DESeq.fisher.L<-sapply(top,Power,input=p_fisher_DESeq.L,ind=ind.L))

(sens.bayes.meta.L<-sapply(delta.cut,Sens,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(spec.bayes.meta.L<-sapply(delta.cut,Spec,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(auc.bayes.L <- auc(sens.bayes.meta.L,spec.bayes.meta.L))

(sens.edgeR.fisher.L<-sapply(all.L,Sens,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(spec.edgeR.fisher.L<-sapply(all.L,Spec,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(auc.edgeR.L <- auc(sens.edgeR.fisher.L,spec.edgeR.fisher.L))

(sens.DESeq.fisher.L<-sapply(all.L,Sens,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(spec.DESeq.fisher.L<-sapply(all.L,Spec,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(auc.DESeq.L <- auc(sens.DESeq.fisher.L,spec.DESeq.fisher.L))

pdf('out/sim.powerROC/SimIB.K2.Low.Power.pdf')
par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.L,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.L,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.L,cex=1,lty=3,lwd=8)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIB.K2.Low.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.L,sens.bayes.meta.L,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.L,sens.edgeR.fisher.L,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.L,sens.DESeq.fisher.L,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.L,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.L,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.L,digits=2),sep=""),cex=2.5,font=2)
dev.off()

(tp.num.bayes.meta.H<-sapply(top,Power,input=delta.mat.H, ind=ind.H))
(tp.num.edgeR.fisher.H<-sapply(top,Power,input=p_fisher_edgeR.H,ind=ind.H))
(tp.num.DESeq.fisher.H<-sapply(top,Power,input=p_fisher_DESeq.H,ind=ind.H))

(sens.bayes.meta.H<-sapply(delta.cut,Sens,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(spec.bayes.meta.H<-sapply(delta.cut,Spec,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(auc.bayes.H <- auc(sens.bayes.meta.H,spec.bayes.meta.H))

(sens.edgeR.fisher.H<-sapply(all.H,Sens,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(spec.edgeR.fisher.H<-sapply(all.H,Spec,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(auc.edgeR.H <- auc(sens.edgeR.fisher.H,spec.edgeR.fisher.H))

(sens.DESeq.fisher.H<-sapply(all.H,Sens,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(spec.DESeq.fisher.H<-sapply(all.H,Spec,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(auc.DESeq.H <- auc(sens.DESeq.fisher.H,spec.DESeq.fisher.H))

pdf('out/sim.powerROC/SimIB.K2.High.Power.pdf')
par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.H,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.H,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.H,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIB.K2.High.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.H,sens.bayes.meta.H,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.H,sens.edgeR.fisher.H,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.H,sens.DESeq.fisher.H,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.H,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.H,digits=2),sep=""),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.H,digits=2),sep=""),cex=2.5,font=2)

dev.off()

########### Sim IB K=5

load("dat/SimIB_K5_Data.rda")
G <- 1000
K <- 5
N <- ncol(count[[1]])
Data.list <- count
X.list <- replicate(K,c(rep(1,N/2),rep(0,N/2)) , simplify=F)

lambda.mean<-0
lambda.var<-10
eta.mean <- -7
eta.var<- 10
m.mean <- -2
m.var <- 10

init <- Initialize(Data.list=Data.list,X.list=X.list,
                   lambda.mean=lambda.mean,lambda.var=lambda.var,
                   eta.mean=eta.mean,eta.var=eta.var,
                   m.mean=m.mean,m.var=m.var,seed=12345)

iteration<- 10000
store <- Store(Data.list=Data.list,X.list=X.list,iteration=iteration)                        

MCMC.out <- MCMCRun(Data.list=Data.list,X.list=X.list,Init.value=init,
                    Store.value = store,iteration=iteration,
                    lambda.mean=lambda.mean, lambda.var=lambda.var, 
                    eta.mean=eta.mean, eta.var=eta.var, 
                    m.mean=m.mean, m.var=m.var, seed=12345) 

burnin<-3000

### power and ROC 

fisher<-function(x) {
  f<-sum(-2*log(x))
  1-pchisq(f,df=2*length(x))
}

delta<-MCMC.out[["Delta"]]
delta.mean<-apply(delta[,-c(1:burnin)],1,mean)
delta.mat<-matrix(delta.mean,nrow=G,ncol=K,byrow=T)

beta<-MCMC.out[["Beta"]]
beta.mean<-apply(beta[,-c(1:burnin)],1,mean)
beta.mat<-matrix(beta.mean,nrow=G,ncol=K,byrow=T)

n<-5
X<-c(rep(1,n),rep(0,n))

group=factor(X)
d=DGEList(counts=count[[1]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value1<-et$table[,3]

d=DGEList(counts=count[[2]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value2<-et$table[,3]

d=DGEList(counts=count[[3]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value3<-et$table[,3]

d=DGEList(counts=count[[4]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value4<-et$table[,3]

d=DGEList(counts=count[[5]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value5<-et$table[,3]

edge.q<-cbind(p_value1,p_value2,p_value3,p_value4,p_value5)

condition=factor(c(rep('A',n),rep('B',n)))
cds1 = newCountDataSet( count[[1]], condition )
cds1 = estimateSizeFactors( cds1 )
cds1 = estimateDispersions( cds1, fitType = c("local") )
res1 = nbinomTest( cds1, "A", "B" )
p1 = res1$pval

cds2 = newCountDataSet( count[[2]], condition )
cds2 = estimateSizeFactors( cds2 )
cds2 = estimateDispersions( cds2, fitType = c("local") )
res2 = nbinomTest( cds2, "A", "B" )
p2 = res2$pval

cds3 = newCountDataSet( count[[3]], condition )
cds3 = estimateSizeFactors( cds3 )
cds3 = estimateDispersions( cds3, fitType = c("local") )
res3 = nbinomTest( cds3, "A", "B" )
p3 = res3$pval

cds4 = newCountDataSet( count[[4]], condition )
cds4 = estimateSizeFactors( cds4 )
cds4 = estimateDispersions( cds4, fitType = c("local") )
res4 = nbinomTest( cds4, "A", "B" )
p4 = res4$pval

cds5 = newCountDataSet( count[[5]], condition )
cds5 = estimateSizeFactors( cds5 )
cds5 = estimateDispersions( cds5, fitType = c("local") )
res5 = nbinomTest( cds5, "A", "B" )
p5 = res5$pval

DESeq.q<-cbind(p1,p2,p3,p4,p5)

rownames(delta.mat)<-paste('gene',1:1000,sep='')
rownames(edge.q)<-paste('gene',1:1000,sep='')
rownames(DESeq.q)<-paste('gene',1:1000,sep='')

p_fisher_edgeR <- apply(edge.q,1,fisher)
p_fisher_DESeq <- apply(DESeq.q,1,fisher)
#q_fisher_edgeR<-p.adjust(apply(edge.q,1,fisher),method='BH')
#q_fisher_DESeq<-p.adjust(apply(DESeq.q,1,fisher),method='BH')

ind.all<-1:200
ind.L<-101:200
ind.H<-1:100
not.ind.all<-201:1000
not.ind.L<-601:1000
not.ind.H<-201:600

top<-seq(2,100,by=2)
delta.cut <- seq(0,1,0.01)
all<-seq(1,1000,10)
all.L<- all.H<- seq(1,500,5)

### For Low mean region: 101:200, 601:1000

delta.mat.L<-delta.mat[c(ind.L,not.ind.L),]
p_fisher_edgeR.L<-p_fisher_edgeR[c(ind.L,not.ind.L)]
p_fisher_DESeq.L<-p_fisher_DESeq[c(ind.L,not.ind.L)]

### For High mean region: 1:100, 201:600

delta.mat.H<-delta.mat[c(ind.H,not.ind.H),]
p_fisher_edgeR.H<-p_fisher_edgeR[c(ind.H,not.ind.H)]
p_fisher_DESeq.H<-p_fisher_DESeq[c(ind.H,not.ind.H)]

attr(delta.mat.L,"method") <- attr(delta.mat.H,"method") <- "Bayes"
attr(delta.mat.L,"study") <- attr(delta.mat.H,"study") <- 5
attr(delta.mat.L,"type") <- attr(delta.mat.H,"type") <- "homo"
attr(delta.mat.L,"region") <- "low"
attr(delta.mat.H,"region") <- "high"

attr(p_fisher_edgeR.L,"method") <- attr(p_fisher_edgeR.H,"method") <- attr(p_fisher_DESeq.L,"method") <- attr(p_fisher_DESeq.H,"method") <- "Fisher"
attr(p_fisher_edgeR.L,"study") <- attr(p_fisher_edgeR.H,"study") <- attr(p_fisher_DESeq.L,"study") <- attr(p_fisher_DESeq.H,"study") <- 5
attr(p_fisher_edgeR.L,"type") <- attr(p_fisher_edgeR.H,"type") <- attr(p_fisher_DESeq.L,"type") <- attr(p_fisher_DESeq.H,"type") <- "homo"
attr(p_fisher_edgeR.L,"region") <- attr(p_fisher_DESeq.L,"region")  <- "low"
attr(p_fisher_edgeR.H,"region") <- attr(p_fisher_DESeq.H,"region")  <- "high"

(tp.num.bayes.meta.L<-sapply(top,Power,input=delta.mat.L, ind=ind.L))
(tp.num.edgeR.fisher.L<-sapply(top,Power,input=p_fisher_edgeR.L,ind=ind.L))
(tp.num.DESeq.fisher.L<-sapply(top,Power,input=p_fisher_DESeq.L,ind=ind.L))

(sens.bayes.meta.L<-sapply(delta.cut,Sens,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(spec.bayes.meta.L<-sapply(delta.cut,Spec,input=delta.mat.L,ind=ind.L,not.ind=not.ind.L))
(auc.bayes.L <- auc(sens.bayes.meta.L,spec.bayes.meta.L))

(sens.edgeR.fisher.L<-sapply(all.L,Sens,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(spec.edgeR.fisher.L<-sapply(all.L,Spec,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(auc.edgeR.L <- auc(sens.edgeR.fisher.L,spec.edgeR.fisher.L))

(sens.DESeq.fisher.L<-sapply(all.L,Sens,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(spec.DESeq.fisher.L<-sapply(all.L,Spec,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(auc.DESeq.L <- auc(sens.DESeq.fisher.L,spec.DESeq.fisher.L))

pdf('out/sim.powerROC/SimIB.K5.Low.Power.pdf')

par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.L,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.L,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.L,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIB.K5.Low.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.L,sens.bayes.meta.L,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.L,sens.edgeR.fisher.L,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.L,sens.DESeq.fisher.L,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.L,digits=2),sep=''),cex=2.5,font=2)

dev.off()


(tp.num.bayes.meta.H<-sapply(top,Power,input=delta.mat.H, ind=ind.H))
(tp.num.edgeR.fisher.H<-sapply(top,Power,input=p_fisher_edgeR.H,ind=ind.H))
(tp.num.DESeq.fisher.H<-sapply(top,Power,input=p_fisher_DESeq.H,ind=ind.H))

(sens.bayes.meta.H<-sapply(delta.cut,Sens,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(spec.bayes.meta.H<-sapply(delta.cut,Spec,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(auc.bayes.H <- auc(sens.bayes.meta.H,spec.bayes.meta.H))

(sens.edgeR.fisher.H<-sapply(all.H,Sens,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(spec.edgeR.fisher.H<-sapply(all.H,Spec,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(auc.edgeR.H <- auc(sens.edgeR.fisher.H,spec.edgeR.fisher.H))

(sens.DESeq.fisher.H<-sapply(all.H,Sens,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(spec.DESeq.fisher.H<-sapply(all.H,Spec,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(auc.DESeq.H <- auc(sens.DESeq.fisher.H,spec.DESeq.fisher.H))

pdf('out/sim.powerROC/SimIB.K5.High.Power.pdf')

par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.H,type='l',cex=1,ylim=c(0,100),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.H,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.H,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimIB.K5.High.ROC.pdf')

par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.H,sens.bayes.meta.H,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.H,sens.edgeR.fisher.H,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.H,sens.DESeq.fisher.H,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.H,digits=2),sep=''),cex=2.5,font=2)

dev.off()

######### Sim II K=2

load("dat/SimII_K2_Data.rda")
G <- 1000
K <- 2
N <- ncol(count[[1]])
Data.list <- count
X.list <- replicate(K,c(rep(1,N/2),rep(0,N/2)) , simplify=F)

lambda.mean<-0
lambda.var<-10
eta.mean <- -7
eta.var<- 10
m.mean <- -2
m.var <- 10

init <- Initialize(Data.list=Data.list,X.list=X.list,
                   lambda.mean=lambda.mean,lambda.var=lambda.var,
                   eta.mean=eta.mean,eta.var=eta.var,
                   m.mean=m.mean,m.var=m.var,seed=12345)

iteration<- 10000
store <- Store(Data.list=Data.list,X.list=X.list,iteration=iteration)                        

MCMC.out <- MCMCRun(Data.list=Data.list,X.list=X.list,Init.value=init,
                    Store.value = store,iteration=iteration,
                    lambda.mean=lambda.mean, lambda.var=lambda.var, 
                    eta.mean=eta.mean, eta.var=eta.var, 
                    m.mean=m.mean, m.var=m.var, seed=12345) 

burnin <- 3000

### power and ROC 

fisher<-function(x) {
  f<-sum(-2*log(x))
  1-pchisq(f,df=2*length(x))
}

delta<-MCMC.out[["Delta"]]
delta.mean<-apply(delta[,-c(1:burnin)],1,mean)
delta.mat<-matrix(delta.mean,nrow=G,ncol=K,byrow=T)

beta<-MCMC.out[["Beta"]]
beta.mean<-apply(beta[,-c(1:burnin)],1,mean)
beta.mat<-matrix(beta.mean,nrow=G,ncol=K,byrow=T)

n<-5
X<-c(rep(1,n),rep(0,n))
group=factor(X)

d=DGEList(counts=count[[1]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value1<-et$table[,3]
d=DGEList(counts=count[[2]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value2<-et$table[,3]

edge.q<-cbind(p_value1,p_value2)

condition=factor(c(rep('A',n),rep('B',n)))
cds1 = newCountDataSet( count[[1]], condition )
cds1 = estimateSizeFactors( cds1 )
cds1 = estimateDispersions( cds1, fitType = c("local") )
res1 = nbinomTest( cds1, "A", "B" )
p1 = res1$pval
cds2 = newCountDataSet( count[[2]], condition )
cds2 = estimateSizeFactors( cds2 )
cds2 = estimateDispersions( cds2, fitType = c("local") )
res2 = nbinomTest( cds2, "A", "B" )
p2 = res2$pval

DESeq.q<-cbind(p1,p2)

rownames(delta.mat)<-paste('gene',1:1000,sep='')
rownames(edge.q)<-paste('gene',1:1000,sep='')
rownames(DESeq.q)<-paste('gene',1:1000,sep='')
p_fisher_edgeR <- apply(edge.q,1,fisher)
p_fisher_DESeq <- apply(DESeq.q,1,fisher)
#q_fisher_edgeR<-p.adjust(apply(edge.q,1,fisher),method='BH')
#q_fisher_DESeq<-p.adjust(apply(DESeq.q,1,fisher),method='BH')

ind.all<-1:300
ind.L<-151:300
indL1<-151:200
indL2<-151:300
ind.H<-1:150
indH1<-1:150
indH2<-101:150

not.ind.all<-301:1000
not.ind.L<-651:1000
not.ind.H<-301:650

top<-seq(5,150,by=5)
delta.cut <- seq(0,1,0.01)
all<-seq(1,1000,10)
all.L<- seq(1,500,5)
all.H<- seq(1,500,5)

### For Low mean region:

delta.mat.L<-delta.mat[c(ind.L,not.ind.L),]
p_fisher_edgeR.L<-p_fisher_edgeR[c(ind.L,not.ind.L)]
p_fisher_DESeq.L<-p_fisher_DESeq[c(ind.L,not.ind.L)]

### For High mean region: 

delta.mat.H<-delta.mat[c(ind.H,not.ind.H),]
p_fisher_edgeR.H<-p_fisher_edgeR[c(ind.H,not.ind.H)]
p_fisher_DESeq.H<-p_fisher_DESeq[c(ind.H,not.ind.H)]


attr(delta.mat.L,"method") <- attr(delta.mat.H,"method") <- "Bayes"
attr(delta.mat.L,"study") <- attr(delta.mat.H,"study") <- 2
attr(delta.mat.L,"type") <- attr(delta.mat.H,"type") <- "hetero"
attr(delta.mat.L,"region") <- "low"
attr(delta.mat.H,"region") <- "high"

attr(p_fisher_edgeR.L,"method") <- attr(p_fisher_edgeR.H,"method") <- attr(p_fisher_DESeq.L,"method") <- attr(p_fisher_DESeq.H,"method") <- "Fisher"
attr(p_fisher_edgeR.L,"study") <- attr(p_fisher_edgeR.H,"study") <- attr(p_fisher_DESeq.L,"study") <- attr(p_fisher_DESeq.H,"study") <- 2
attr(p_fisher_edgeR.L,"type") <- attr(p_fisher_edgeR.H,"type") <- attr(p_fisher_DESeq.L,"type") <- attr(p_fisher_DESeq.H,"type") <- "hetero"
attr(p_fisher_edgeR.L,"region") <- attr(p_fisher_DESeq.L,"region")  <- "low"
attr(p_fisher_edgeR.H,"region") <- attr(p_fisher_DESeq.H,"region")  <- "high"

(tp.num.bayes.meta.L<-sapply(top,Power,input=delta.mat.L, ind=list(indL1,indL2)))
(tp.num.edgeR.fisher.L<-sapply(top,Power,input=p_fisher_edgeR.L,ind=ind.L))
(tp.num.DESeq.fisher.L<-sapply(top,Power,input=p_fisher_DESeq.L,ind=ind.L))

(sens.bayes.meta.L<-sapply(delta.cut,Sens,input=delta.mat.L,ind=list(indL1,indL2),not.ind=not.ind.L))
(spec.bayes.meta.L<-sapply(delta.cut,Spec,input=delta.mat.L,ind=list(indL1,indL2),not.ind=not.ind.L))
(auc.bayes.L <- auc(sens.bayes.meta.L,spec.bayes.meta.L))

(sens.edgeR.fisher.L<-sapply(all.L,Sens,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(spec.edgeR.fisher.L<-sapply(all.L,Spec,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(auc.edgeR.L <- auc(sens.edgeR.fisher.L,spec.edgeR.fisher.L))

(sens.DESeq.fisher.L<-sapply(all.L,Sens,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(spec.DESeq.fisher.L<-sapply(all.L,Spec,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(auc.DESeq.L <- auc(sens.DESeq.fisher.L,spec.DESeq.fisher.L))


pdf('out/sim.powerROC/SimII.K2.Low.Power.pdf')
par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.L,type='l',cex=1,ylim=c(0,150),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.L,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.L,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimII.K2.Low.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.L,sens.bayes.meta.L,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.L,sens.edgeR.fisher.L,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.L,sens.DESeq.fisher.L,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.L,digits=2),sep=''),cex=2.5,font=2)
dev.off()

(tp.num.bayes.meta.H<-sapply(top,Power,input=delta.mat.H, ind=list(indH1,indH2)))
(tp.num.edgeR.fisher.H<-sapply(top,Power,input=p_fisher_edgeR.H,ind=ind.H))
(tp.num.DESeq.fisher.H<-sapply(top,Power,input=p_fisher_DESeq.H,ind=ind.H))

(sens.bayes.meta.H<-sapply(delta.cut,Sens,input=delta.mat.H,ind=list(indH1,indH2),not.ind=not.ind.H))
(spec.bayes.meta.H<-sapply(delta.cut,Spec,input=delta.mat.H,ind=list(indH1,indH2),not.ind=not.ind.H))
(auc.bayes.H <- auc(sens.bayes.meta.H,spec.bayes.meta.H))

(sens.edgeR.fisher.H<-sapply(all.H,Sens,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(spec.edgeR.fisher.H<-sapply(all.H,Spec,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(auc.edgeR.H <- auc(sens.edgeR.fisher.H,spec.edgeR.fisher.H))

(sens.DESeq.fisher.H<-sapply(all.H,Sens,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(spec.DESeq.fisher.H<-sapply(all.H,Spec,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(auc.DESeq.H <- auc(sens.DESeq.fisher.H,spec.DESeq.fisher.H))

pdf('out/sim.powerROC/SimII.K2.High.Power.pdf')

par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.H,type='l',cex=1,ylim=c(0,150),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.H,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.H,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimII.K2.High.ROC.pdf')
par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.H,sens.bayes.meta.H,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.H,sens.edgeR.fisher.H,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.H,sens.DESeq.fisher.H,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.H,digits=2),sep=''),cex=2.5,font=2)
dev.off()


######### Sim II K=5

load("dat/SimII_K5_Data.rda")
G <- 1000
K <- 5
N <- ncol(count[[1]])
Data.list <- count
X.list <- replicate(K,c(rep(1,N/2),rep(0,N/2)) , simplify=F)

lambda.mean<-0
lambda.var<-10
eta.mean <- -7
eta.var<- 10
m.mean <- -2
m.var <- 10

init <- Initialize(Data.list=Data.list,X.list=X.list,
                   lambda.mean=lambda.mean,lambda.var=lambda.var,
                   eta.mean=eta.mean,eta.var=eta.var,
                   m.mean=m.mean,m.var=m.var,seed=12345)

iteration<- 10000
store <- Store(Data.list=Data.list,X.list=X.list,iteration=iteration)                        

MCMC.out <- MCMCRun(Data.list=Data.list,X.list=X.list,Init.value=init,
                    Store.value = store,iteration=iteration,
                    lambda.mean=lambda.mean, lambda.var=lambda.var, 
                    eta.mean=eta.mean, eta.var=eta.var, 
                    m.mean=m.mean, m.var=m.var, seed=12345) 

burnin <- 3000

### power and ROC 

fisher<-function(x) {
  f<-sum(-2*log(x))
  1-pchisq(f,df=2*length(x))
}

delta<-MCMC.out[["Delta"]]
delta.mean<-apply(delta[,-c(1:burnin)],1,mean)
delta.mat<-matrix(delta.mean,nrow=G,ncol=K,byrow=T)

beta<-MCMC.out[["Beta"]]
beta.mean<-apply(beta[,-c(1:burnin)],1,mean)
beta.mat<-matrix(beta.mean,nrow=G,ncol=K,byrow=T)

n<-5
X<-c(rep(1,n),rep(0,n))

group=factor(X)
d=DGEList(counts=count[[1]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value1<-et$table[,3]

d=DGEList(counts=count[[2]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value2<-et$table[,3]

d=DGEList(counts=count[[3]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value3<-et$table[,3]

d=DGEList(counts=count[[4]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value4<-et$table[,3]

d=DGEList(counts=count[[5]],group=group)
d <- calcNormFactors(d)
d <- estimateCommonDisp(d)
d <- estimateTagwiseDisp(d)
et <- exactTest(d)
p_value5<-et$table[,3]

edge.q<-cbind(p_value1,p_value2,p_value3,p_value4,p_value5)

condition=factor(c(rep('A',n),rep('B',n)))
cds1 = newCountDataSet( count[[1]], condition )
cds1 = estimateSizeFactors( cds1 )
cds1 = estimateDispersions( cds1, fitType = c("local") )
res1 = nbinomTest( cds1, "A", "B" )
p1 = res1$pval

cds2 = newCountDataSet( count[[2]], condition )
cds2 = estimateSizeFactors( cds2 )
cds2 = estimateDispersions( cds2, fitType = c("local") )
res2 = nbinomTest( cds2, "A", "B" )
p2 = res2$pval

cds3 = newCountDataSet( count[[3]], condition )
cds3 = estimateSizeFactors( cds3 )
cds3 = estimateDispersions( cds3, fitType = c("local") )
res3 = nbinomTest( cds3, "A", "B" )
p3 = res3$pval

cds4 = newCountDataSet( count[[4]], condition )
cds4 = estimateSizeFactors( cds4 )
cds4 = estimateDispersions( cds4, fitType = c("local") )
res4 = nbinomTest( cds4, "A", "B" )
p4 = res4$pval

cds5 = newCountDataSet( count[[5]], condition )
cds5 = estimateSizeFactors( cds5 )
cds5 = estimateDispersions( cds5, fitType = c("local") )
res5 = nbinomTest( cds5, "A", "B" )
p5 = res5$pval

DESeq.q<-cbind(p1,p2,p3,p4,p5)

rownames(delta.mat)<-paste('gene',1:1000,sep='')
rownames(edge.q)<-paste('gene',1:1000,sep='')
rownames(DESeq.q)<-paste('gene',1:1000,sep='')
p_fisher_edgeR <- apply(edge.q,1,fisher)
p_fisher_DESeq <- apply(DESeq.q,1,fisher)
#q_fisher_edgeR<-p.adjust(apply(edge.q,1,fisher),method='BH')
#q_fisher_DESeq<-p.adjust(apply(DESeq.q,1,fisher),method='BH')

ind.all<-1:300
ind.L<-151:300
indL1<-NULL
indL2<-151:165
indL3<-151:210
indL4<-151:255
indL5<-201:300
ind.H<-1:150

not.ind.all<-301:1000
not.ind.L<-651:1000
not.ind.H<-301:650

top<-seq(5,150,by=5)
delta.cut <- seq(0,1,0.01)
all<-seq(1,1000,10)
all.L<- seq(1,500,5)
all.H<- seq(1,500,5)

### For Low mean region:

delta.mat.L<-delta.mat[c(ind.L,not.ind.L),]
p_fisher_edgeR.L<-p_fisher_edgeR[c(ind.L,not.ind.L)]
p_fisher_DESeq.L<-p_fisher_DESeq[c(ind.L,not.ind.L)]

### For High mean region: 

delta.mat.H<-delta.mat[c(ind.H,not.ind.H),]
p_fisher_edgeR.H<-p_fisher_edgeR[c(ind.H,not.ind.H)]
p_fisher_DESeq.H<-p_fisher_DESeq[c(ind.H,not.ind.H)]

attr(delta.mat.L,"method") <- attr(delta.mat.H,"method") <- "Bayes"
attr(delta.mat.L,"study") <- attr(delta.mat.H,"study") <- 5
attr(delta.mat.L,"type") <- attr(delta.mat.H,"type") <- "hetero"
attr(delta.mat.L,"region") <- "low"
attr(delta.mat.H,"region") <- "high"

attr(p_fisher_edgeR.L,"method") <- attr(p_fisher_edgeR.H,"method") <- attr(p_fisher_DESeq.L,"method") <- attr(p_fisher_DESeq.H,"method") <- "Fisher"
attr(p_fisher_edgeR.L,"study") <- attr(p_fisher_edgeR.H,"study") <- attr(p_fisher_DESeq.L,"study") <- attr(p_fisher_DESeq.H,"study") <- 5
attr(p_fisher_edgeR.L,"type") <- attr(p_fisher_edgeR.H,"type") <- attr(p_fisher_DESeq.L,"type") <- attr(p_fisher_DESeq.H,"type") <- "hetero"
attr(p_fisher_edgeR.L,"region") <- attr(p_fisher_DESeq.L,"region")  <- "low"
attr(p_fisher_edgeR.H,"region") <- attr(p_fisher_DESeq.H,"region")  <- "high"

(tp.num.bayes.meta.L<-sapply(top,Power,input=delta.mat.L, ind=list(indL2,indL3,indL4,indL5)))
(tp.num.edgeR.fisher.L<-sapply(top,Power,input=p_fisher_edgeR.L,ind=ind.L))
(tp.num.DESeq.fisher.L<-sapply(top,Power,input=p_fisher_DESeq.L,ind=ind.L))

(sens.bayes.meta.L<-sapply(delta.cut,Sens,input=delta.mat.L,ind=list(indL1,indL2,indL3,indL4,indL5),not.ind=not.ind.L))
(spec.bayes.meta.L<-sapply(delta.cut,Spec,input=delta.mat.L,ind=list(indL1,indL2,indL3,indL4,indL5),not.ind=not.ind.L))
(auc.bayes.L <- auc(sens.bayes.meta.L,spec.bayes.meta.L))

(sens.edgeR.fisher.L<-sapply(all.L,Sens,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(spec.edgeR.fisher.L<-sapply(all.L,Spec,input=p_fisher_edgeR.L,ind=ind.L,not.ind=not.ind.L))
(auc.edgeR.L <- auc(sens.edgeR.fisher.L,spec.edgeR.fisher.L))

(sens.DESeq.fisher.L<-sapply(all.L,Sens,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(spec.DESeq.fisher.L<-sapply(all.L,Spec,input=p_fisher_DESeq.L,ind=ind.L,not.ind=not.ind.L))
(auc.DESeq.L <- auc(sens.DESeq.fisher.L,spec.DESeq.fisher.L))

pdf('out/sim.powerROC/SimII.K5.Low.Power.pdf')

par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.L,type='l',cex=1,ylim=c(0,150),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.L,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.L,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimII.K5.Low.ROC.pdf')

par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.L,sens.bayes.meta.L,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.L,sens.edgeR.fisher.L,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.L,sens.DESeq.fisher.L,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.L,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.L,digits=2),sep=''),cex=2.5,font=2)
dev.off()

(tp.num.bayes.meta.H<-sapply(top,Power,input=delta.mat.H, ind=ind.H))
(tp.num.edgeR.fisher.H<-sapply(top,Power,input=p_fisher_edgeR.H,ind=ind.H))
(tp.num.DESeq.fisher.H<-sapply(top,Power,input=p_fisher_DESeq.H,ind=ind.H))

(sens.bayes.meta.H<-sapply(delta.cut,Sens,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(spec.bayes.meta.H<-sapply(delta.cut,Spec,input=delta.mat.H,ind=ind.H,not.ind=not.ind.H))
(auc.bayes.H <- auc(sens.bayes.meta.H,spec.bayes.meta.H))

(sens.edgeR.fisher.H<-sapply(all.H,Sens,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(spec.edgeR.fisher.H<-sapply(all.H,Spec,input=p_fisher_edgeR.H,ind=ind.H,not.ind=not.ind.H))
(auc.edgeR.H <- auc(sens.edgeR.fisher.H,spec.edgeR.fisher.H))

(sens.DESeq.fisher.H<-sapply(all.H,Sens,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(spec.DESeq.fisher.H<-sapply(all.H,Spec,input=p_fisher_DESeq.H,ind=ind.H,not.ind=not.ind.H))
(auc.DESeq.H <- auc(sens.DESeq.fisher.H,spec.DESeq.fisher.H))

pdf('out/sim.powerROC/SimII.K5.High.Power.pdf')

par(font.lab=2)
par(cex.lab=1.6)
par(cex.axis=2)
plot(top,tp.num.bayes.meta.H,type='l',cex=1,ylim=c(0,150),
     main=NULL,ylab='Number of True Positives',
     xlab='Number of top ranked genes',lwd=5,lty=1,font=2)
lines(top,tp.num.edgeR.fisher.H,cex=1,lty=2,lwd=5)
lines(top,tp.num.DESeq.fisher.H,cex=1,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
dev.off()

pdf('out/sim.powerROC/SimII.K5.High.ROC.pdf')

par(font.lab=2)
par(cex.lab=2)
par(cex.axis=2)
plot(1-spec.bayes.meta.H,sens.bayes.meta.H,xlab='1-specificity',ylab='sensitivity',
     pch=19,cex=0.3,main=NULL,type='l',lty=1,lwd=5,font=2)
lines(1-spec.edgeR.fisher.H,sens.edgeR.fisher.H,lty=2,lwd=5)
lines(1-spec.DESeq.fisher.H,sens.DESeq.fisher.H,lty=3,lwd=7)
box(which = "plot", lty = "solid",lwd=2)
text(0.6,0.6,paste('BayesMetaSeq;',format(auc.bayes.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.5,paste('edgeR;',format(auc.edgeR.H,digits=2),sep=''),cex=2.5,font=2)
text(0.6,0.4,paste('DESeq;',format(auc.DESeq.H,digits=2),sep=''),cex=2.5,font=2)
dev.off()

####### Sim III K=3

source("src/DPM161002.R")
load('dat/SimIII_Data.rda')
load('dat/simIIIout.rdata') ## includes: "beta.de"  "delta.de"

K <- 3
N <- ncol(count[[1]])
Data.list <- count
X.list <- replicate(K,c(rep(1,N/2),rep(0,N/2)) , simplify=F)
G <- nrow(Data.list[[1]])
K <- length(Data.list)
libsize <- lapply(Data.list,colSums)

es_seq =function (y,X,lib) {
  y=array(y)
  v1=log((y[which(X==1)]+1)/(lib[which(X==1)]))
  v2=log((y[which(X==0)]+1)/(lib[which(X==0)]))
  u=mean(v1) - mean(v2)
  return(u)
}

beta.obs<-matrix(rep(0,G*K),nrow=G,ncol=K) 
for (g in 1:G){
  for (k in 1:K){
    lib<-libsize[[k]]
    beta.obs[g,k]<-es_seq(y=Data.list[[k]][g,],X=X.list[[k]],lib=lib)
  }
}

beta300 <- beta.obs[1:300,]

#delta.de <- MCMC.out[['Delta']][1:900,]
burnin <- 3000
deltamean300 <- matrix(apply(delta.de[,-c(1:burnin)],1,mean),
                       byrow=T,nrow=300,ncol=K)

set.seed(12345)
C.init <- 10 
pi.alpha<- 2  
iteration <- 10000
thin <- 20 
cluster.out <- DPM(Beta.obs = beta300, Delta = delta.de,C.init = C.init, pi.alpha = pi.alpha, iteration = iteration, thin = thin) 

cluster.top <- cluster.out[,-c(1:(burnin/thin+1))]
rownames(cluster.top) <- rownames(cluster.out) <- rownames(deltamean300) <- rownames(beta300) <- paste('gene',1:300,sep=' ') 

copy.upper.lower <- function(m) 
{
  m[lower.tri(m)] <- t(m)[lower.tri(m)]
  m
}

mydist <- function(y) {
  diss.mat <- matrix(,nrow=nrow(y),ncol=nrow(y))
  rownames(diss.mat) <- colnames(diss.mat) <- rownames(y)
  diag(diss.mat) <- 1
  for (i in 1:nrow(diss.mat)) {
    for (j in i:ncol(diss.mat)){
      diss.mat[i,j] <- sum(y[i,]==y[j,])/ncol(y)    
    }
  }
  diss.mat <- copy.upper.lower(diss.mat)
  return(1-diss.mat)
}

dist.mat <- mydist(y=cluster.top)

setwd('out/')
results = ConsensusClusterPlus(d=t(cluster.top),maxK=6,reps=50,pItem=0.8,pFeature=1,title="SimIII Consensus Clustering",clusterAlg="hc",
    innerLinkage="ward.D2",finalLinkage="ward.D2", distance="mydist",seed=1262118388.71279,plot="png")

cluster1.index <- which(results[[6]]$consensusClass ==1 )
cluster2.index <- which(results[[6]]$consensusClass ==2 )
cluster3.index <- which(results[[6]]$consensusClass ==3 )
cluster4.index <- which(results[[6]]$consensusClass ==4 )
cluster5.index <- which(results[[6]]$consensusClass ==5 )
cluster6.index <- which(results[[6]]$consensusClass ==6 )

apply(deltamean300[cluster1.index,],2,mean)
apply(beta300[cluster1.index,],2,mean)
apply(deltamean300[cluster2.index,],2,mean)
apply(beta300[cluster2.index,],2,mean)
apply(deltamean300[cluster3.index,],2,mean)
apply(beta300[cluster3.index,],2,mean)
apply(deltamean300[cluster4.index,],2,mean)
apply(beta300[cluster4.index,],2,mean)
apply(deltamean300[cluster5.index,],2,mean)
apply(beta300[cluster5.index,],2,mean)
apply(deltamean300[cluster6.index,],2,mean)
apply(beta300[cluster6.index,],2,mean)

de.6cluster<-deltamean300[c(cluster1.index,cluster2.index,
                            cluster3.index,cluster4.index,
                            cluster5.index,cluster6.index),]

obs.es.6cluster<- beta300[c(cluster1.index,cluster2.index,
                            cluster3.index,cluster4.index,
                            cluster5.index,cluster6.index),]

input<-de.6cluster*sign(obs.es.6cluster)
rownames(input) <- rownames(beta300)[c(cluster1.index,cluster2.index,cluster3.index,cluster4.index,cluster5.index,cluster6.index)]

png('Simu Six DE clusters.png',width=350,height=450)
hm<-heatmap.2(input, symm=F,main=NULL,cexCol=0.1,cexRow=0.2,scale='none',symbreaks=T,
              key=T, keysize=1,symkey=T, dendrogram=c('none'),density.info="none", trace="none",Rowv=F,Colv=F,labRow = FALSE,
              col=bluered,breaks=seq(-1,1,by=0.001))
dev.off()


